use std::time::SystemTime;

use chrono::Local;
use eframe::{
    egui::{RichText, Window},
    App,
};

use crate::prelude::CanonicalName;

#[derive(Default)]
pub struct ClockWidget;

impl CanonicalName for ClockWidget {
    fn canonical_name() -> String {
        "Clock".into()
    }
}

impl App for ClockWidget {
    fn update(&mut self, ctx: &eframe::egui::Context, frame: &mut eframe::Frame) {
        Window::new("Clock")
            .title_bar(false)
            .resizable(false)
            .movable(true)
            .open(&mut true)
            .show(ctx, |ui| {
                ui.label(
                    RichText::new(Local::now().format("%H:%M:%S").to_string())
                        .size(64.)
                        .strong(),
                );
                if ui.is_visible() {
                    ctx.request_repaint();
                }
            });
    }
}
