use eframe::WindowBuilder;
use egui::{Key, Window};

use crate::prelude::CanonicalName;

#[derive(Default)]
pub struct TodoWidget {
    todos: Vec<(String, bool)>,
    _goal_input_cache: String,
}

impl CanonicalName for TodoWidget {
    fn canonical_name() -> String {
        "Todos".into()
    }
}

impl eframe::App for TodoWidget {
    fn update(&mut self, ctx: &egui::Context, frame: &mut eframe::Frame) {
        Window::new("Todos").show(ctx, |ui| {
            self.todos.sort_by_key(|a| !a.1);
            self.todos.retain_mut(|t| {
                ui.horizontal(|ui| {
                    ui.checkbox(&mut t.1, t.0.clone());
                    !ui.button("remove").clicked()
                })
                .inner
            });

            ui.horizontal(|ui| {
                ui.text_edit_singleline(&mut self._goal_input_cache);
                if ctx.input(|i| i.key_pressed(Key::Enter)) || ui.button("add").clicked() {
                    self.todos.push((self._goal_input_cache.clone(), false));
                    self._goal_input_cache = String::default();
                }
            });
        });
    }
}
